(* Program to Calculate the Helicity Amplitudes in Eq. (5.109) of ITC 

 Compatible with FC 9.2 and 9.3
 
 Last Version: 22/11/2021
 Author: Jorge C. Romao
 email: jorge.romao@tecnico.ulisboa.pt
*)

Remove["Global`*"]


prop[p_, m_] := GS[p] + m


dp[s_]:= (1 + s GA[5])/2


U[p_,s_]:= dp[s] . SpinorU[p,0]

UBar[p_,s_]:=  SpinorUBar[p,0] . dp[-s]


(* Only for feynCalc 9.2   

Myds=Function[{p,i},If[i==1, U[p,1] UBar[p,1],If[i==2, U[p,-1] UBar[p,-1]]]] 
PolS=Function[{k,p,l,i},If[i==1,  U[p,l]  UBar[k,l],If[i==2,  2  U[k,-l]  UBar[p,-l]]]]

*)
  
(*
To be compatible with FeynCalc 9.3 we have to separate the spinor and 
spinorBar in the definitions of GS[p] and Polarization sums.

The code below works for FeynCalc 9.2 and 9.3
*)


PolSConjU=Function[{k,p,l,i}, If[i==1, 2 U[k,l],If[i==2, 2 U[p,-l]]]]

PolSConjUBar=Function[{k,p,l,i}, If[i==1,UBar[p,l],If[i==2, UBar[k,-l]]]]

MydsU=Function[{p,i},If[i==1, U[p,1],If[i==2, U[p,-1]]]] 

MydsUBar=Function[{p,i},If[i==1, UBar[p,1],If[i==2, UBar[p,-1]]]] 

M1[s1_,s2_,l1_,l2_]:=Sum[(UBar[p2,s2] . PolSConjU[k2,p2,l2,i1] PolSConjUBar[k2,p2,l2,i1] . MydsU[p1,i2] MydsUBar[p1,i2] . PolSConjU[k1,p1,l1,i3] PolSConjUBar[k1,p1,l1,i3] . U[p1,s1]),{i1,1,2},{i2,1,2},{i3,1,2}]-Sum[(UBar[p2,s2] . PolSConjU[k2,p2,l2,i1] PolSConjUBar[k2,p2,l2,i1] . MydsU[k1,i2] MydsUBar[k1,i2] . PolSConjU[k1,p1,l1,i3] PolSConjUBar[k1,p1,l1,i3] . U[p1,s1]),{i1,1,2},{i2,1,2},{i3,1,2}]

res1[s1_,s2_,l1_,l2_]:=DiracSimplify[M1[s1,s2,l1,l2],DiracSubstitute67->True]/t/N11^2


M2[s1_,s2_,l1_,l2_]:=Sum[UBar[p2,s2] . PolSConjU[k1,p2,l1,i1] PolSConjUBar[k1,p2,l1,i1]  . MydsU[p1,i2] MydsUBar[p1,i2] . PolSConjU[k2,p1,l2,i3] PolSConjUBar[k2,p1,l2,i3] .  U[p1,s1],{i1,1,2},{i2,1,2},{i3,1,2}] - Sum[UBar[p2,s2] . PolSConjU[k1,p2,l1,i1] PolSConjUBar[k1,p2,l1,i1] . MydsU[k2,i2] MydsUBar[k2,i2] . PolSConjU[k2,p1,l2,i3] PolSConjUBar[k2,p1,l2,i3] .  U[p1,s1],{i1,1,2},{i2,1,2},{i3,1,2}]

res2[s1_,s2_,l1_,l2_]:=DiracSimplify[M2[s1,s2,l1,l2],DiracSubstitute67->True]/u/N12^2

simp1={Spinor[p1,0] . Spinor[p1,0]->0,Spinor[p1,0] . Spinor[p2,0] -> MySP[p1,p2] + MySPc[p2,p1],Spinor[p1,0] . Spinor[k1,0] -> MySP[p1,k1] + MySPc[k1,p1],Spinor[p1,0] . Spinor[k2,0] -> MySP[p1,k2] + MySPc[k2,p1],Spinor[p2,0] . Spinor[p1,0] -> MySP[p2,p1] + MySPc[p1,p2],Spinor[p2,0] . Spinor[p2,0]->0,Spinor[p2,0] . Spinor[k1,0] -> MySP[p2,k1] + MySPc[k1,p2],Spinor[p2,0] . Spinor[k2,0] -> MySP[p2,k2] + MySPc[k2,p2],Spinor[k1,0] . Spinor[p1,0] ->MySP[k1,p1] + MySPc[p1,k1],Spinor[k1,0] . Spinor[p2,0] ->MySP[k1,p2] + MySPc[p2,k1],Spinor[k1,0] . Spinor[k1,0] ->0,Spinor[k1,0] . Spinor[k2,0] ->MySP[k1,k2] + MySPc[k2,k1],Spinor[k2,0] . Spinor[p1,0] ->MySP[k2,p1] + MySPc[p1,k2],Spinor[k2,0] . Spinor[p2,0] ->MySP[k2,p2] + MySPc[p2,k2],Spinor[k2,0] . Spinor[k1,0] ->MySP[k2,k1] + MySPc[k1,k2],Spinor[k2,0] . Spinor[k2,0] ->0}


simp2={Spinor[p1,0] . DiracMatrix[5] . Spinor[p1,0]->0,Spinor[p1,0] . DiracMatrix[5] . Spinor[p2,0] -> -MySP[p1,p2] + MySPc[p2,p1],Spinor[p1,0] . DiracMatrix[5] . Spinor[k1,0] -> -MySP[p1,k1] + MySPc[k1,p1],Spinor[p1,0] . DiracMatrix[5] . Spinor[k2,0] -> -MySP[p1,k2] + MySPc[k2,p1],Spinor[p2,0] . DiracMatrix[5] . Spinor[p1,0] -> -MySP[p2,p1] + MySPc[p1,p2],Spinor[p2,0] . DiracMatrix[5] . Spinor[p2,0]->0,Spinor[p2,0] . DiracMatrix[5] . Spinor[k1,0] -> -MySP[p2,k1] + MySPc[k1,p2],Spinor[p2,0] . DiracMatrix[5] . Spinor[k2,0] -> -MySP[p2,k2] + MySPc[k2,p2],Spinor[k1,0] . DiracMatrix[5] . Spinor[p1,0] ->-MySP[k1,p1] + MySPc[p1,k1],Spinor[k1,0] . DiracMatrix[5] . Spinor[p2,0] ->-MySP[k1,p2] + MySPc[p2,k1],Spinor[k1,0] . DiracMatrix[5] . Spinor[k1,0] ->0,Spinor[k1,0] . DiracMatrix[5] . Spinor[k2,0] ->-MySP[k1,k2] + MySPc[k2,k1],Spinor[k2,0] . DiracMatrix[5] . Spinor[p1,0] ->-MySP[k2,p1] + MySPc[p1,k2],Spinor[k2,0] . DiracMatrix[5] . Spinor[p2,0] ->-MySP[k2,p2] + MySPc[p2,k2],Spinor[k2,0] . DiracMatrix[5] . Spinor[k1,0] ->-MySP[k2,k1] + MySPc[k1,k2],Spinor[k2,0] . DiracMatrix[5] . Spinor[k2,0] ->0}



simp=Flatten[{simp1,simp2}];



sim={MySP[p2,p1]->-MySP[p1,p2],MySPc[p2,p1]->-MySPc[p1,p2],MySP[k2,k1]->-MySP[k1,k2],MySPc[k2,k1]->-MySPc[k1,k2], MySP[k1,p1]->-MySP[p1,k1],MySPc[k1,p1]->-MySPc[p1,k1],MySP[k2,p1]->-MySP[p1,k2],MySPc[k2,p1]->-MySPc[p1,k2],MySP[k1,p2]->-MySP[p2,k1],MySPc[k1,p2]->-MySPc[p2,k1], MySP[k2,p2]->-MySP[p2,k2],MySPc[k2,p2]->-MySPc[p2,k2]}


kin={MySP[p1, p2]*MySPc[p1, p2] -> s, MySP[k1, k2]*MySPc[k1, k2] -> s, MySP[p1, k1]*MySPc[p1, k1] -> -t, MySP[p2, k2]*MySPc[p2, k2] -> -t, MySP[p1, k2]*MySPc[p1, k2] -> -u, MySP[p2, k1]*MySPc[p2, k1] -> -u,N11->Sqrt[-2 t],N12->Sqrt[-2 u]}


norma={N11->(2 sp[p1, k1] spc[p1, k1])^(1/2),N12->(2 sp[p1, k2] spc[p1, k2])^(1/2)}

M[s1_,s2_,l1_,l2_]:=Simplify[((-e^2(res1[s1,s2,l1,l2]+res2[s1,s2,l1,l2]) /.simp) /. sim) /. norma] /. {MySP[p_, q_]->sp[p,q], MySPc[p_, q_]->spc[p,q]}
